// cpukeeper
// Interface to the Opencores.org Mini-RISC CPU core module
// For more information, visit www.opencores.org.

module cpukeeper(clk, reset,
		 positive_vblank,
		 instr_addr, instr_data,
		 maccess_addr, maccess_read, maccess_we, maccess_write,
		 kbd_data, status_read, cfg_write, cfg_we);

   input clk, reset;
   input positive_vblank;

   output [10:0] instr_addr;
   input [11:0] instr_data;

   output [7:0] maccess_addr;
   input [3:0] 	maccess_read;
   output [3:0] maccess_we, maccess_write;
   input [7:0] 	kbd_data;
   input [7:0] 	status_read;
   output [7:0] cfg_write;
   output 	cfg_we;

   wire [7:0] portb_read = { 4'b0000, maccess_read };
   wire [7:0] portb_write;
   wire minirisc_reset;
   assign minirisc_reset = (reset || positive_vblank);
   wire [7:0] trisa, trisb, trisc;

   mrisc mycpu(clk, minirisc_reset,
	       instr_addr, instr_data,
	       kbd_data, portb_read, status_read,
	       maccess_addr, portb_write, cfg_write,
	       trisa, trisb, trisc,
	       clk, 1'b0);

   assign maccess_write = portb_write[3:0];
   assign maccess_we = trisb[3:0];
   assign cfg_we = trisc[0];

endmodule

`include "risc_core.v"
`include "register_file.v"
`include "primitives_xilinx.v"
`include "presclr_wdt.v"
`include "alu.v"
