module dummy_cpu(clk, reset,
		 positive_vblank,
		 maccess_addr, maccess_read, maccess_we, maccess_write,
		 status_read, cfg_write, cfg_we);
   input clk, reset;
   input positive_vblank;
   output [7:0] maccess_addr;
   input [3:0] 	maccess_read;
   output [3:0] maccess_we, maccess_write;
   input [7:0] 	status_read;
   output [7:0] cfg_write;
   output 	cfg_we;

   reg [7:0] 	maccess_addr;
   reg [3:0] 	maccess_we, maccess_write;
   reg [7:0] 	cfg_write;
   reg 		cfg_we;
   reg [4:0] 	start_config;
   reg [2:0] pacman_state;
   reg [9:0] pacman_pos;
   reg [4:0] pacman_row;

   always @(posedge clk) begin
      if(reset) begin
	 maccess_addr <= 0;
	 maccess_we <= 0;
	 maccess_write <= 0;
	 cfg_write <= 0;
	 cfg_we <= 0;

	 pacman_state <= 0;
	 pacman_pos <= 0;
	 pacman_row <= 0;

	 start_config <= 0;

      end else begin // if (reset)

	 if(positive_vblank) begin

	    if(pacman_state == 5)
	       pacman_state <= 0;
	    else
	       pacman_state <= pacman_state + 1;

	    if(pacman_pos == 640) begin
	       pacman_pos <= 0;
	       if(pacman_row == 14)
	          pacman_row <= 0;
	       else
	          pacman_row <= pacman_row + 1;
	    end else
	       pacman_pos <= pacman_pos + 1;

	    start_config <= 1;
	    //if(status_read[0])
	       maccess_addr <= 1;
	 end

	 // Configuration write cycle
	 if(start_config != 0) begin
	    if(cfg_we) begin
	       cfg_we <= 0;
	       if(start_config == 23)
		  start_config <= 0;
	    end else
	       case(start_config)

		 1: begin
		    cfg_write <= 8'b00000011;
		    cfg_we <= 1;
		    start_config <= start_config + 1;
		 end
		 2: begin
		    cfg_write <= 8'b00000000;
		    cfg_we <= 1;
		    start_config <= start_config + 1;
		 end

                 // Sprite 0
		 3: begin
		    cfg_write <= { 3'b00, pacman_state[2:1], 3'b000 };
		    cfg_we <= 1;
		    start_config <= start_config + 1;
		 end
		 4: begin
		    cfg_write <= { 3'b000, pacman_pos[9:5] };
		    cfg_we <= 1;
		    start_config <= start_config + 1;
		 end
		 5: begin
		    cfg_write <= { 3'b000, pacman_pos[4:0] };
		    cfg_we <= 1;
		    start_config <= start_config + 1;
		 end
		 6: begin
		    cfg_write <= { 3'b000, pacman_row[4:0] };
		    cfg_we <= 1;
		    start_config <= start_config + 1;
		 end
		 7: begin
		    cfg_write <= 8'b00000000;
		    cfg_we <= 1;
		    start_config <= start_config + 1;
		 end

                 // Sprite 1
		 8: begin
		    cfg_write <= 8'b00000000;
		    cfg_we <= 1;
		    start_config <= start_config + 1;
		 end
		 9: begin
		    cfg_write <= 8'b00000000;
		    cfg_we <= 1;
		    start_config <= start_config + 1;
		 end
		 10: begin
		    cfg_write <= 8'b00000000;
		    cfg_we <= 1;
		    start_config <= start_config + 1;
		 end
		 11: begin
		    cfg_write <= 8'b00000000;
		    cfg_we <= 1;
		    start_config <= start_config + 1;
		 end
		 12: begin
		    cfg_write <= 8'b00000011;
		    cfg_we <= 1;
		    start_config <= start_config + 1;
		 end

                 // Sprite 2
		 13: begin
		    cfg_write <= 8'b00000000;
		    cfg_we <= 1;
		    start_config <= start_config + 1;
		 end
		 14: begin
		    cfg_write <= 8'b00000000;
		    cfg_we <= 1;
		    start_config <= start_config + 1;
		 end
		 15: begin
		    cfg_write <= 8'b00000000;
		    cfg_we <= 1;
		    start_config <= start_config + 1;
		 end
		 16: begin
		    cfg_write <= 8'b00000000;
		    cfg_we <= 1;
		    start_config <= start_config + 1;
		 end
		 17: begin
		    cfg_write <= 8'b00000011;
		    cfg_we <= 1;
		    start_config <= start_config + 1;
		 end

                 // Sprite 3
		 18: begin
		    cfg_write <= 8'b00000000;
		    cfg_we <= 1;
		    start_config <= start_config + 1;
		 end
		 19: begin
		    cfg_write <= 8'b00000000;
		    cfg_we <= 1;
		    start_config <= start_config + 1;
		 end
		 20: begin
		    cfg_write <= 8'b00000000;
		    cfg_we <= 1;
		    start_config <= start_config + 1;
		 end
		 21: begin
		    cfg_write <= 8'b00000000;
		    cfg_we <= 1;
		    start_config <= start_config + 1;
		 end
		 22: begin
		    cfg_write <= 8'b00000011;
		    cfg_we <= 1;
		    start_config <= start_config + 1;
		 end

	       endcase
	 end


	 // Maze RAM load with dummy data
	 if(maccess_addr != 0) begin
	    if(maccess_we != 0) begin
	       maccess_addr <= maccess_addr + 1;
	       maccess_we <= 0;
	    end else begin
	       maccess_write <= maccess_addr[4:1];
	       maccess_we <= 4'b1111;
	    end
	 end

      end	 
	 
   end // always @ (posedge clk)
   
   
endmodule // dummy_cpu

